summaryrefslogtreecommitdiffstats
path: root/khtml/misc/khtmllayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/misc/khtmllayout.h')
-rw-r--r--khtml/misc/khtmllayout.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/khtml/misc/khtmllayout.h b/khtml/misc/khtmllayout.h
index e4fb531a1..a67e7019e 100644
--- a/khtml/misc/khtmllayout.h
+++ b/khtml/misc/khtmllayout.h
@@ -18,22 +18,22 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
- This widget holds some useful definitions needed for layouting Elements
+ This widget holds some useful definitions needed for tqlayouting Elements
*/
#ifndef HTML_LAYOUT_H
#define HTML_LAYOUT_H
/*
* this namespace contains definitions for various types needed for
* layouting.
*/
namespace khtml
{
const int UNDEFINED = -1;
- // alignment
+ // tqalignment
enum VAlign { VNone=0, Bottom, VCenter, Top, Baseline };
enum HAlign { HDefault, Left, HCenter, Right, HNone = 0 };
@@ -103,7 +103,7 @@ namespace khtml
unsigned type : 3;
bool quirk : 1;
} l;
- Q_UINT32 _length;
+ TQ_UINT32 _length;
};
};
@@ -18,22 +18,22 @@
#define HTML_LAYOUT_H
/*
- * this namespace contains definitions for various types needed for
- * layouting.
+ * this namespace tqcontains definitions for various types needed for
+ * tqlayouting.
*/
namespace khtml